/*!***************************************************************************
*! FILE NAME  : os_map.js
*! DESCRIPTION: functions for OpenLayers Open Street Map API
*! Copyright (C) 2011 Elphel, Inc
*! -----------------------------------------------------------------------------**
*!
*!  This program is free software: you can redistribute it and/or modify
*!  it under the terms of the GNU General Public License as published by
*!  the Free Software Foundation, either version 3 of the License, or
*!  (at your option) any later version.
*!
*!  This program is distributed in the hope that it will be useful,
*!  but WITHOUT ANY WARRANTY; without even the implied warranty of
*!  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*!  GNU General Public License for more details.
*!
*!  You should have received a copy of the GNU General Public License
*!  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*! -----------------------------------------------------------------------------**
*! 
*! $Log: os_map.js,v $
*!
*/

var osm_eyesis_size = new OpenLayers.Size(28,40);
var osm_eyesis_offset = new OpenLayers.Pixel(-(osm_eyesis_size.w/2), -osm_eyesis_size.h);
var osm_eyesis_icon = new OpenLayers.Icon('files/map_icons/eyesis_icon.png', osm_eyesis_size, osm_eyesis_offset);

var osm_small_dot_size = new OpenLayers.Size(12,12);
var osm_small_dot_offset = new OpenLayers.Pixel(-(osm_small_dot_size.w/2), -osm_small_dot_size.h);
var osm_small_dot_icon = new OpenLayers.Icon('files/map_icons/small_dot.png', osm_small_dot_size, osm_small_dot_offset);

var osmap;
var osm_markers;
var osm_points = new Array();

var osm_CurrentMarker;

var zoom=13;

function osm_init(){
    var options = {theme: null};
    
    OpenLayers.ImgPath = "http://js.mapbox.com/theme/dark/";
    
    osmap = new OpenLayers.Map("osmap", options);
    
    //osmap.addControl(new OpenLayers.Control.LayerSwitcher({'ascending':false}));
    
      OpenLayers.Layer.MapQuestOSM = OpenLayers.Class(OpenLayers.Layer.XYZ, {
	  name: "MapQuestOSM",
	  //attribution: "Data CC-By-SA by <a href='http://openstreetmap.org/'>OpenStreetMap</a>",
	  sphericalMercator: true,
	  url: ' http://otile1.mqcdn.com/tiles/1.0.0/osm/${z}/${x}/${y}.png',
	  clone: function(obj) {
	      if (obj == null) {
		  obj = new OpenLayers.Layer.OSM(
		  this.name, this.url, this.getOptions());
	      }
	      obj = OpenLayers.Layer.XYZ.prototype.clone.apply(this, [obj]);
	      return obj;
	  },
	  CLASS_NAME: "OpenLayers.Layer.MapQuestOSM"
      });
  
    var mapquest_osm_layer = new OpenLayers.Layer.MapQuestOSM();
    osmap.addLayer(mapquest_osm_layer);
    
    //osmap.addLayer(new OpenLayers.Layer.OSM());
        
    osm_markers = new OpenLayers.Layer.Markers( "Markers" );
        
    osmap.addLayer(osm_markers);
 
}

function osm_place_point(mark,n) {
   
    if (n==0) {
	var point = new OpenLayers.LonLat(mark.longitude,mark.latitude)
	    .transform(
		new OpenLayers.Projection("EPSG:4326"), // transform from WGS 1984
		osmap.getProjectionObject()             // to Spherical Mercator Projection
	    );      
        osmap.setCenter(point, zoom);
    }
  
    if (n==0) var icon = osm_eyesis_icon.clone();    
    else      var icon = osm_small_dot_icon.clone();
    
    osm_create_marker(mark,icon);
        
}

function osm_create_marker(mark,icon) {
  
    var i = mark.href;
    //var i = mark.href.substr(mark.href.lastIndexOf('/')+1);
    
    var point = new OpenLayers.LonLat(mark.longitude,mark.latitude)
	.transform(
            new OpenLayers.Projection("EPSG:4326"), // transform from WGS 1984
            osmap.getProjectionObject()             // to Spherical Mercator Projection
        );

    osm_points[i] = new OpenLayers.Marker(point,icon);
    osm_markers.addMarker(osm_points[i]);
    
    osm_points[i].events.register("click", osm_points[i], function(e){
		//osm_set_current_position(mark);
		//panorama.setPano(mark.href);
		//var req = "?kml="+settings.kml+"&href="+mark.href;
		getMapNodes(serverURL,mark.href);
    });
    osm_points[i].events.register("mouseover", osm_points[i], function(e){
		if (mark.href!=osm_CurrentMarker.href) osm_points[i].setUrl('files/map_icons/small_dot_blue.png');
    });
    osm_points[i].events.register("mouseout", osm_points[i], function(e){
		if (mark.href!=osm_CurrentMarker.href) osm_points[i].setUrl('files/map_icons/small_dot.png');
    });    
    
}

function osm_set_current_position(mark) { 
    osm_set_icon(osm_CurrentMarker,osm_small_dot_icon.clone());
    osm_set_icon(mark,osm_eyesis_icon.clone());    
    osm_CurrentMarker = mark;
}

function osm_remove_marker(i) {
	osm_markers.removeMarker(osm_points[i]);
}

function osm_set_icon(mark,icon) {
    osm_remove_marker(mark.href);
    //osm_remove_marker(mark.href.substr(mark.href.lastIndexOf('/')+1));
    osm_create_marker(mark,icon);    
}
